@@ -65,8 +65,19 @@ def call_template(self, *args, **kw):
     if template is _marker:
         self._template = template = BaseTemplateFile(self.filename)
 
-    return template.__of__(self)(self, *args, **kw)
+    if IAcquirer.providedBy(template):
+        template = template.__of__(self)
+
+    return template(self, *args, **kw)
+
+def get_macros(self):
+    template = getattr(self, '_template', _marker)
+    if template is _marker:
+        self._template = template = BaseTemplateFile(self.filename)
+
+    return template.__of__(self).macros
 
 FiveViewPageTemplateFile.__get__ = get_bound_template
 ZopeViewPageTemplateFile.__get__ = get_bound_template
 PageTemplateFile.__call__ = call_template
+PageTemplateFile.macros = property(get_macros)
